@@ -1,5 +1,6 @@
 import os
 import time
+import logging, sys
 import requests
 import numpy as np
 import pandas as pd
@@ -24,12 +25,18 @@ class apiBase:
         raise NotImplementedError
 
     def interval_check(self, interval):
-        if 'h' in interval:            
-            interval = int(interval.split('h')[0]) * 3600
+        if 'h' in interval.lower():            
+            interval = int(interval.lower().split('h')[0]) * 3600
+            minutes = int(interval / 60)    
+        elif 'm' in interval.lower():
+            interval = int(interval.lower().split('m')[0]) * 60
+            minutes = int(interval / 60)
+        elif 'd' in interval.lower():
+            interval = int(interval.lower().split('d')[0]) * 3600 * 24
             minutes = int(interval / 60)
-            return interval, minutes
         else:
-            raise Exception('Only hours supportted right now')
+            raise Exception('Only days, hours and minutes are supportted at the moment')
+        return interval, minutes
 
     def symbol_check(self, symbol):
         # symbol = 'btcusd' if symbol is None else symbol
@@ -88,6 +95,7 @@ class apiBase:
         start = start or self.start
         end = end or int(time.time())
 
+        interval_str = interval     # to give it to .get() func
         interval, minutes = self.interval_check(interval)
 
         total_entries = (end - start) // interval
@@ -105,13 +113,14 @@ class apiBase:
             if end_batch >= end:
                 end_batch = end
             try:
-                df_temp = self.get(symbol=symbol, start=str(start_batch), end=str(end_batch))
+                df_temp = self.get(symbol=symbol, interval=interval_str, start=str(start_batch), end=str(end_batch))
                 if df_temp is None:     # Try this fix for other apis
                     print('    Debug: df_temp is empty')
                     assert len(df) == 0, 'Debug: empty df_temp in middle of download'
                     df_temp = df
             except Exception as e:
-                print(e, '\nError between timestamps: ', start_batch, end_batch)
+                # raise e
+                print(e, '\nDebug: error between timestamps: ', start_batch, end_batch)
                 if steps <= 1: return None
 
             df_temp = pd.concat([df, df_temp])
@@ -143,7 +152,7 @@ class apiBase:
         
         return df
 
-    def update(self, path):
+    def update(self, path, **kwargs):
         # assert os.path.exists(path), "path doesn't exists!"
         if not os.path.exists(path):    # Disabled
             assert '.csv' in path, "Not a valid .csv location!"
@@ -152,10 +161,10 @@ class apiBase:
             df.to_csv(path)
             return
         
-        df = pd.read_csv(path, index_col='timestamp')
+        df = pd.read_csv(path, index_col=0)
 
         last_timestamp = df.index[-1]
-        updates = self.get_hist(start=last_timestamp)
+        updates = self.get_hist(start=last_timestamp, **kwargs)
 
         df_final = pd.concat([df, updates])
         df_final = df_final[~df_final.index.duplicated(keep='first')]
@@ -163,13 +172,13 @@ class apiBase:
 
         return df_final
 
-    def calc_start(self, limit, start=None, end=None, interval=3600):
+    def calc_start(self, limit, start=None, end=None, interval=3600, scale=1):
         current_time = int(time.time())
         if isinstance(interval, str):
             interval = self.interval_check(interval)[0]
 
         limit = self.limit if limit is None else limit
-        limit = int(limit / (interval / 3600))
+        limit = int(limit / scale)      # for 8h funding scaling
         end = current_time if end is None else end
         if start is None:
             start = end - (interval * (limit-1))  # limit -1 to be sure to get the latest hour
