@@ -6,7 +6,7 @@ import pandas as pd
 from tradingfeatures import apiBase
 from tradingfeatures.apis.binance.base import binanceBase
 from tradingfeatures.apis.binance.funding import binanceFunding
-from tradingfeatures.apis.binance.order_book import binanceOrderBook
+from tradingfeatures.apis.binance.order_book import binanceOrderBook, binanceRecentTrades
 
 
 class binance(binanceBase):
@@ -16,6 +16,7 @@ class binance(binanceBase):
 
         self.funding = binanceFunding()
         self.orderbook = binanceOrderBook()
+        self.recenttrades = binanceRecentTrades()
 
     def update(self, path, update_all=False, *args, **kwargs):        
         if update_all:
