@@ -25,6 +25,9 @@ class bitstampBase(apiBase):
             'ethusd': 'ethusd',
             'ethbtc': 'ethbtc',
             'ltcusd': 'ltcusd',
+            'bchusd': 'bthusd',
+            'eosusd': 'eosusd',
+            'xrpusd': 'xrpusd',
         }
     
     def get(self,
@@ -39,20 +42,22 @@ class bitstampBase(apiBase):
             return_r: bool = False,
             ):
 
-        start, end, out_of_range = self.calc_start(limit, start, end)
-        if out_of_range:
-            return self.get_hist(symbol=symbol, start=start, end=end) 
-        
         address = address or self.address
         address = self.base_address + address
-        symbol = symbol or 'btcusd'
-        symbol = self.symbol_dict[symbol]    
+        symbol = symbol or 'btcusd'        
+
+        start, end, out_of_range = self.calc_start(limit, start, end)
+        if out_of_range:
+            return self.get_hist(symbol=symbol, start=start, end=end)
+
+        symbol = self.symbol_check(symbol)  # had to give raw symbol above, this has to be after
         
         if query is None:
             limit = self.limit if limit is None else limit     
-            address = address + f'/{symbol}/'   
+            address = address + f'/{symbol}/'
+            interval_int, minutes = self.interval_check(interval)
 
-            query = {'start': start,'end': end, 'step': 3600, 'limit': limit}
+            query = {'start': start,'end': end, 'step': interval_int, 'limit': limit}
 
         r = self.response_handler(address, params=query, timeout=60)
         
@@ -73,4 +78,7 @@ class bitstampBase(apiBase):
         return super(bitstampBase, self).get_hist(
             *args, **kwargs
         )
+
+    def _start_check(self, address, symbol):
+        raise Exception('Cant sort oldest item')
     
